DpadFocusScope class final

Inheritance

Constructors

DpadFocusScope({Key? key, FocusScopeNode? focusScopeNode, FocusNode? parentNode, bool autofocus = false, bool canRequestFocus = true, bool? skipTraversal, bool rebuildOnFocusChange = true, FocusTraversalPolicy? policy, bool descendantsAreFocusable = true, bool descendantsAreTraversable = true, bool includeSemantics = true, DpadScopeEventCallback? onUp, DpadScopeEventCallback? onDown, DpadScopeEventCallback? onLeft, DpadScopeEventCallback? onRight, DpadEventCallback? onSelect, DpadEventCallback? onBack, KeyEventResult onKeyEvent(FocusNode, KeyEvent)?, void onFocusChanged(FocusScopeNode, bool)?, void onFocusDisabledWhenWasFocused(FocusScopeNode)?, required Widget builder(BuildContext, FocusScopeNode)})

Properties

autofocus bool
final
builder Widget Function(BuildContext, FocusScopeNode)
final
canRequestFocus bool
final
descendantsAreFocusable bool
final
descendantsAreTraversable bool
final
focusScopeNode FocusScopeNode?
final
hashCode int
The hash code for this object.
no setterinherited
includeSemantics bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onBack DpadEventCallback?
final
onDown DpadScopeEventCallback?
final
onFocusChanged → void Function(FocusScopeNode, bool)?
final
onFocusDisabledWhenWasFocused → void Function(FocusScopeNode)?
final
onKeyEvent KeyEventResult Function(FocusNode, KeyEvent)?
final
onLeft DpadScopeEventCallback?
final
onRight DpadScopeEventCallback?
final
onSelect DpadEventCallback?
final
onUp DpadScopeEventCallback?
final
parentNode FocusNode?
final
policy FocusTraversalPolicy
final
rebuildOnFocusChange bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipTraversal bool?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited